==> mobroute-0.5.0.tar.gz: mobroute-v0.5.0/README.md <==
# Mobroute
[![builds.sr.ht status](https://builds.sr.ht/~mil/mobroute.svg?search=tags:master)](https://builds.sr.ht/~mil/mobroute?search=tags%3Amaster)

**Mobroute** is a **general purpose FOSS public transportation router
(e.g. trip planner) Go library and CLI** that works by directly ingesting
timetable (GTFS) data from transit agencies themselves (sourced from
the [Mobility Database](https://database.mobilitydata.org/)). After
data has been fetched, routing calculations can be run offline, and
locally / on-device (as opposed to making a network call). Overall,
Mobroute aims to offer an opensource framework (both CLI & library)
for integrating data-provider-agnostic GTFS public transit capabilities
(integrated GTFS ETL, GTFS multisource support, and routing algorithm)
into applications to get users from point-a to point-b via public transit
without comprising privacy or user freedoms.

In addition to the Mobroute Go library & CLI, the related subproject,
[the Transito app](http://git.sr.ht/~mil/transito) offers fully integrated
routing functionality on mobile devices (Android & Linux) utilizing
Mobroute's Go library's API.

The Mobroute & Transito projects overall are currently
in active development but generally currently usable
on [mobile](http:/git.sr.ht/~mil/transito) & via
[the CLI](doc/userguide_cli.md) and looking for more users &
testers. Mobroute & Transito work in many well-connected metros which
have publicly available GTFS data, to name a few: Lisbon, NYC, Brussels,
Krakow, and Bourges. You can see [sample routes at the automated test
results page](https://ci.lrdu.org/tests_results/), [check for your metro
here](http://mdb.lrdu.org), and [see details on the Transito mobile app
here](http://git.sr.ht/~mil/transito).

## **Documentation:**

- **Mobroute Doc:** [CLI Userguide](./doc/userguide_cli.md), [Go API Userguide](./doc/userguide_goapi.md), [What is MDBID](./doc/doc_mdbid.md), [Tunable Parameters](./doc/doc_tunables.md), [Development](./doc/doc_dev.md), [Contribute](./doc/doc_contribute.md), [Roadmap](./doc/doc_roadmap.md)
- **Project Management:** [Bugtracker](https://todo.sr.ht/~mil/mobroute-tickets), [Mailing List](https://lists.sr.ht/~mil/mobroute-devel)
- **CI:** [Test Results (master)](http://ci.lrdu.org/tests_results/), [Test Results (by commit)](http://ci.lrdu.org/tests_results_refs/), [Generated APKs](http://ci.lrdu.org/android/)
- **Related:** [Transito](http://git.sr.ht/~mil/transito) (Mobile App), [Mobsql](http://git.sr.ht/~mil/mobsql) (GTFS-to-SQLite ETL library)

## **Project Overview / Featureset:**

- Well-executed **singlemodal public transportation routing** via GTFS data
  - Project focuses on implementing only GTFS routing providing for algorithmic & codebase simplicity
  - Other routers bill themselves as "multimodal"; Mobroute is proudly singlemodal (doesn't integrate automobile/OSM/PBF data)
  - Overall.. *does one thing well*: public transportation routing
- Integration of **automatic GTFS dataimport** & ETL out-of-the-box via [the Mobility Database](https://database.mobilitydata.org/)
  - Frees user from having to source & manually download/import GTFS zip archives
  - System automatically downloads the data needed for a routing requests *upon use*
  - Supports using multiple GTFS sources independently and in combination for single routing requests
  - See [Mobsql](http://git.sr.ht/~mil/mobsql) for details on ETL pipeline, uses SQLite under the hood
- Efficient algorithmic routing via the **Connection Scan Algorithm** (CSA)
  - Being a singlemodal router lends Mobroute's design to implementation simplicity
  - The well academically studied CSA algorithm is utilized: see [paper details here](https://i11www.iti.kit.edu/extra/publications/dpsw-isftr-13.pdf)
  - CSA is non-graphbased, simple, and Mobroute's CSA implementation is well tested
- Targeted to **on-device and offline usage**
  - Designed to be used on-device and offline once data is fetched
  - Run your routing request right on your mobile device for the privacy conscious
- Fully thought-out **small, simple, & modular design supporting library, CLI, & mobile usage**
  - Built in Go, the design of the project is small and modular
  - 3 primary components:
    - [Mobsql](http://git.sr.ht/~mil/mobsql) (GTFS-to-SQLite ETL pipeline: CLI + Go API)
    - [Mobroute](http://git.sr.ht/~mil/mobroute) (Core routing algorithm via CSA: CLI + Go API)
    - [Transito](http://git.sr.ht/~mil/transito) (Graphical mobile application for Android & Linux)
  - Mobsql and Mobroute can be used as both a CLI OR as a Go API as a library in your application
  - Transito, Mobroute's mobile application is written in Go (via [Gio](https://gioui.org/)) and uses Mobroute's Go API


## **Architecture:**

**The Mobroute project is composed of 3 separate codebases / smaller projects:**
  - [Mobsql](http://git.sr.ht/~mil/mobsql): is a GTFS-to-SQL ETL tool which
    pulls GTFS sources from the MobilityDB into a SQLite database. It exposes
    both a CLI & a Go library (consumed by Mobroute).
  - [Mobroute](http://git.sr.ht/~mil/mobroute): is the core routing tool. This
    project handles interfacing Mobsql via its public Go API and then once the
    DB is loaded, opens the DB and performs routing calculations (currently via
    the Connection Scan Algorithm). It exposes both a CLI & a Go library (
    consumed by Transito).
  - [Transito](http://git.sr.ht/~mil/transito): is a simple Android & Linux GUI 
    app to use Mobroute. It allows querying from/to via Nominatim and
    performing routing calculations on-the-go via Mobroute's underlying
    routing mechanism (note this implicitly integrates Mobsql as well).

==> mobroute-0.7.0.tar.gz: mobroute-v0.7.0/README.md <==
# Mobroute
[![builds.sr.ht status](https://builds.sr.ht/~mil/mobroute/commits/master.svg)](https://builds.sr.ht/~mil/mobroute?search=tags%3Amaster)

**Mobroute** is a **general purpose FOSS public transportation router
(e.g. trip planner) Go library and CLI** that works by directly ingesting
timetable (GTFS) data from transit agencies themselves (sourced from
the [Mobility Database](https://database.mobilitydata.org/)). After
data has been fetched, routing calculations can be run offline, and
locally / on-device (as opposed to making a network call). Overall,
Mobroute aims to offer an opensource framework (both CLI & library)
for integrating data-provider-agnostic GTFS public transit capabilities
(integrated GTFS ETL, GTFS multisource support, and routing algorithm)
into applications to get users from point-a to point-b via public transit
without comprising privacy or user freedoms.

In addition to the Mobroute Go library & CLI, the related subproject,
[the Transito app](http://git.sr.ht/~mil/transito) offers fully integrated
routing functionality on mobile devices (Android & Linux) utilizing
Mobroute's Go library.

The Mobroute & Transito projects overall are currently
in active development but generally currently usable
on [mobile](http:/git.sr.ht/~mil/transito) & via
[the CLI](doc/userguide_cli.md) and looking for more users &
testers. Mobroute & Transito work in many well-connected metros which
have publicly available GTFS data, to name a few: Lisbon, NYC, Brussels,
Krakow, and Bourges. You can see [sample routes at the automated test
results page](https://ci.lrdu.org/tests_results/), [check for your metro
here](http://mdb.lrdu.org), and [see details on the Transito mobile app
here](http://git.sr.ht/~mil/transito).

## **Documentation:**

- **Mobroute Doc:** [CLI Userguide](./doc/userguide_cli.md), [Go Library Userguide](./doc/userguide_golibrary.md), [Available GTFS Feeds](./doc/doc_gtfsfeeds.md), [Tunable Parameters](./doc/doc_tunables.md), [Development](./doc/doc_dev.md), [Contribute](./doc/doc_contribute.md), [Roadmap](./doc/doc_roadmap.md)
- **Project Management:** [Bugtracker](https://todo.sr.ht/~mil/mobroute-tickets), [Mailing List](https://lists.sr.ht/~mil/mobroute-devel)
- **CI:** [Test Results (master)](http://ci.lrdu.org/tests_results/), [Test Results (by commit)](http://ci.lrdu.org/tests_results_refs/), [Generated APKs](http://ci.lrdu.org/android/), [Builds](https://builds.sr.ht/~mil/mobroute?search=tags%3Amaster)
- **Related:** [Transito](http://git.sr.ht/~mil/transito) (Mobile App), [Mobsql](http://git.sr.ht/~mil/mobsql) (GTFS-to-SQLite ETL library)

## **Project Overview / Featureset:**

- Well-executed **singlemodal public transportation routing** via GTFS data
  - Project focuses on implementing only GTFS routing providing for algorithmic & codebase simplicity
  - Other routers bill themselves as "multimodal"; Mobroute is proudly singlemodal (doesn't integrate automobile/OSM/PBF data)
  - Overall.. *does one thing well*: public transportation routing
- Integration of **automatic GTFS dataimport** & ETL out-of-the-box via [the Mobility Database](https://database.mobilitydata.org/)
  - Frees user from having to source & manually download/import GTFS zip archives
  - System automatically downloads the data needed for a routing requests *upon use*
  - Supports using multiple GTFS sources independently and in combination for single routing requests
  - See [Mobsql](http://git.sr.ht/~mil/mobsql) for details on ETL pipeline, uses SQLite under the hood
- Efficient algorithmic routing via the **Connection Scan Algorithm** (CSA)
  - Being a singlemodal router lends Mobroute's design to implementation simplicity
  - The well academically studied CSA algorithm is utilized: see [paper details here](https://i11www.iti.kit.edu/extra/publications/dpsw-isftr-13.pdf)
  - CSA is non-graphbased, simple, and Mobroute's CSA implementation is well tested
- Targeted to **on-device and offline usage**
  - Designed to be used on-device and offline once data is fetched
  - Run your routing request right on your mobile device for the privacy conscious
- Fully thought-out **small, simple, & modular design supporting library, CLI, & mobile usage**
  - Built in Go, the design of the project is small and modular
  - 3 primary components:
    - [Mobsql](http://git.sr.ht/~mil/mobsql) (GTFS-to-SQLite ETL pipeline: CLI + Go Library)
    - [Mobroute](http://git.sr.ht/~mil/mobroute) (Core routing algorithm via CSA: CLI + Go Library)
    - [Transito](http://git.sr.ht/~mil/transito) (Graphical mobile application for Android & Linux)
  - Mobsql and Mobroute can be used as both a CLI OR as a Go library in your application
  - Transito, Mobroute's mobile application is written in Go (via [Gio](https://gioui.org/)) and uses Mobroute's Go Library


## **Architecture:**

**The Mobroute project is composed of 3 separate codebases / smaller projects:**
  - [Mobsql](http://git.sr.ht/~mil/mobsql): is a GTFS-to-SQL ETL tool which
    pulls GTFS sources from the MobilityDB into a SQLite database. It exposes
    both a CLI & a Go library (consumed by Mobroute).
  - [Mobroute](http://git.sr.ht/~mil/mobroute): is the core routing tool.
    This project handles interfacing the Mobsql Go Library and then once
    the DB is loaded, opens the DB and performs routing calculations
    (currently via the Connection Scan Algorithm). It exposes both a CLI &
    a Go library ( consumed by Transito).
  - [Transito](http://git.sr.ht/~mil/transito): is a simple Android & Linux GUI 
    app to use Mobroute. It allows querying from/to via Nominatim and
    performing routing calculations on-the-go via Mobroute's underlying
    routing mechanism (note this implicitly integrates Mobsql as well).

## **Funding**

This project is funded through [NGI0 Entrust](https://nlnet.nl/entrust),
a fund established by [NLnet](https://nlnet.nl) with financial
support from the European Commission's [Next Generation
Internet](https://ngi.eu) program. Learn more at the [NLnet project
page](https://nlnet.nl/project/Mobroute).

[<img src="https://nlnet.nl/logo/banner.png" alt="NLnet foundation logo" width="20%" />](https://nlnet.nl)
[<img src="https://nlnet.nl/image/logos/NGI0_tag.svg" alt="NGI Zero Logo" width="20%" />](https://nlnet.nl/entrust)
